@@ -326,6 +326,7 @@ class RunDatabases(enum.Enum):
     OPTIMIZER_RUNS_SCHEDULE_DB = "runs_schedule"
     RUN_DATA_DB = "run_data"
     PORTFOLIO_VALUE_DB = "portfolio_value"
+    HISTORICAL_PORTFOLIO_VALUE = "historical_portfolio_value"
     ORDERS_DB = "orders"
     TRADES_DB = "trades"
     TRANSACTIONS_DB = "transactions"
@@ -371,10 +372,6 @@ class SignalsAttrs(enum.Enum):
     CONTENT = "content"
 
 
-class InitializationEventTopics(enum.Enum):
-    EXCHANGE = "exchanges"
-
-
 class InitializationEventExchangeTopics(enum.Enum):
     POSITIONS = "positions"
     BALANCE = "balance"
@@ -385,3 +382,22 @@ class InitializationEventExchangeTopics(enum.Enum):
     PRICE = "price"
     ORDER_BOOK = "order_book"
     FUNDING = "funding"
+
+
+class UserInputTentacleTypes(enum.Enum):
+    TRADING_MODE = "trading_mode"
+    EVALUATOR = "evaluator"
+    EXCHANGE = "exchange"
+    UNDEFINED = "undefined"
+
+
+class UserInputTypes(enum.Enum):
+    INT = "int"
+    FLOAT = "float"
+    BOOLEAN = "boolean"
+    OPTIONS = "options"
+    MULTIPLE_OPTIONS = "multiple-options"
+    TEXT = "text"
+    OBJECT = "object"
+    OBJECT_ARRAY = "object_array"
+    STRING_ARRAY = "string_array"
